# sn_peers_acquisition

Provides utilities for discovering bootstrap peers on a given system.

It handles `--peer` arguments across all bins, as well as `SAFE_PEERS` or indeed picking up an initial set of `network-conacts` from a provided, or hard-coded url.